@@ -297,10 +297,10 @@ class Aphantasia(ImageGenerator):
 
 
 if __name__ == '__main__':
-    prompt = "'Tempus Fugit' by Salvador Dali"
+    prompt = "Gucci flip flops"
     lr = 0.5
     img_save_freq = 1
-    num_generations = 64
+    num_generations = 200
     num_random_crops = 32
     height = 256
     width = 512
@@ -317,7 +317,7 @@ if __name__ == '__main__':
     )
 
     _gen_img_list, fft_logits_list_ = aphantasia.generate_from_prompt(
-        prompt="'Tempus Fugit', by Escher",
+        prompt="Gucci flip flops",
         lr=lr,
         img_save_freq=img_save_freq,
         num_generations=num_generations,
