@@ -7,6 +7,7 @@ from typing import *
 
 import torch
 import torchvision
+import numpy as np
 from PIL import Image
 from omegaconf import OmegaConf
 from forks.taming_transformers.taming.models.vqgan import VQModel
@@ -118,7 +119,9 @@ class TamingDecoder(ImageGenerator):
         img_save_freq: int = 1,
         num_generations: int = 200,
         num_random_crops: int = 20,
-        img_batch=None,
+        init_img_path=None,
+        loss_type: str = 'cosine_similarity',
+        loss_clip_value: float = None,
         **kwargs,
     ):
         batch_size = 1
@@ -130,17 +133,25 @@ class TamingDecoder(ImageGenerator):
             self.embed_size,
         ).to(self.device)
 
-        z_logits = torch.nn.Parameter(
-            torch.sinh(1.9 * torch.arcsinh(z_logits)), )
+        if init_img_path is None:
+            z_logits = torch.nn.Parameter(
+                torch.sinh(1.9 * torch.arcsinh(z_logits)), )
+        else:
+            pil_img = Image.open(init_img_path)
+            pil_img = pil_img.convert('RGB')
 
-        if img_batch is not None:
-            clip_img_z_logits = self.get_clip_img_encodings(img_batch)
-            clip_img_z_logits = clip_img_z_logits.detach().clone()
+            init_img = torch.tensor(np.asarray(pil_img)).to(
+                self.device).float()[None, :]
+            init_img /= 255.
+            init_img = init_img.permute(0, 3, 1, 2)
 
-            z, _, [_, _, indices] = self.vqgan_model.encode(img_batch)
+            # clip_img_z_logits = self.get_clip_img_encodings(init_img)
+            # clip_img_z_logits = clip_img_z_logits.detach().clone()
+
+            z, _, [_, _, indices] = self.vqgan_model.encode(init_img)
 
             z_logits = torch.nn.Parameter(z)
-            img_z_logits = z.detach().clone()
+            # img_z_logits = z.detach().clone()
 
         optimizer = torch.optim.AdamW(
             params=[z_logits],
@@ -167,12 +178,17 @@ class TamingDecoder(ImageGenerator):
                 target_img_height=self.target_img_size,
             )
 
-            loss += 10 * self.compute_clip_loss(x_rec_stacked, prompt)
+            loss += 10 * self.compute_clip_loss(
+                x_rec_stacked,
+                prompt,
+                loss_type,
+                loss_clip_value,
+            )
 
-            if img_batch is not None:
-                loss += -10 * torch.cosine_similarity(z_logits,
-                                                      img_z_logits).mean()
-            # if img_batch is not None:
+            # if init_img is not None:
+            #     loss += -10 * torch.cosine_similarity(z_logits,
+            #                                           img_z_logits).mean()
+            # if init_img is not None:
             #     loss += -10 * torch.cosine_similarity(
             #         self.get_clip_img_encodings(x_rec), clip_img_z_logits).mean()
 
@@ -225,12 +241,15 @@ class TamingDecoder(ImageGenerator):
 
 
 if __name__ == '__main__':
-    prompt = "Pokemon of type fire"
+    prompt = "Landscape of Costa Rica"
     lr = 0.5
     img_save_freq = 1
-    num_generations = 64
-    num_random_crops = 64
-    img_batch = None
+    num_generations = 32
+    num_random_crops = 16
+    # init_img_path = "alien.png"
+    init_img_path = None
+    loss_type = 'cosine_similarity'
+    loss_clip_value = .1
 
     taming_decoder = TamingDecoder()
     gen_img_list, z_logits_list = taming_decoder.generate_from_prompt(
@@ -239,22 +258,24 @@ if __name__ == '__main__':
         img_save_freq=img_save_freq,
         num_generations=num_generations,
         num_random_crops=num_random_crops,
-        img_batch=img_batch,
+        init_img_path=init_img_path,
+        loss_type=loss_type,
+        loss_clip_value=loss_clip_value,
     )
 
-    _gen_img_list, z_logits_list_ = taming_decoder.generate_from_prompt(
-        prompt="Pokemon of type grass",
-        lr=lr,
-        img_save_freq=img_save_freq,
-        num_generations=num_generations,
-        num_random_crops=num_random_crops,
-        img_batch=img_batch,
-    )
+    # _gen_img_list, z_logits_list_ = taming_decoder.generate_from_prompt(
+    #     prompt="Pokemon of type grass",
+    #     lr=lr,
+    #     img_save_freq=img_save_freq,
+    #     num_generations=num_generations,
+    #     num_random_crops=num_random_crops,
+    #     init_img_path=init_img_path,
+    # )
 
-    z_logits_interp_list = [z_logits_list[-1], z_logits_list_[-1]]
+    # z_logits_interp_list = [z_logits_list[-1], z_logits_list_[-1]]
 
-    duration_list = [0.7] * len(z_logits_interp_list)
-    interpolate_img_list = taming_decoder.interpolate(
-        z_logits_list=z_logits_interp_list,
-        duration_list=duration_list,
-    )
+    # duration_list = [0.7] * len(z_logits_interp_list)
+    # interpolate_img_list = taming_decoder.interpolate(
+    #     z_logits_list=z_logits_interp_list,
+    #     duration_list=duration_list,
+    # )
